@@ -144,6 +144,15 @@ esyd() {
     disable_pid)
         [ -c '/dev/syd/sandbox/pid:off' ]
         ;;
+    enabled_fs)
+        [ -c '/dev/syd/sandbox/fs?' ]
+        ;;
+    enable_fs)
+        [ -c '/dev/syd/sandbox/fs:on' ]
+        ;;
+    disable_fs)
+        [ -c '/dev/syd/sandbox/fs:off' ]
+        ;;
     enabled_walk)
         [ -c '/dev/syd/sandbox/walk?' ]
         ;;
@@ -423,6 +432,38 @@ esyd() {
         # nodeny is shorthand for all glob capabilities.
         _esyd_path "deny/all" "${op}" "${@}"
         ;;
+    allow_fs)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/fs' '+' "${@}"
+        ;;
+    disallow_fs)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/fs' "${op}" "${@}"
+        ;;
+    deny_fs)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/fs' '+' "${@}"
+        ;;
+    nodeny_fs)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/fs' "${op}" "${@}"
+        ;;
     allow_walk)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
@@ -1315,6 +1356,22 @@ esyd() {
             _esyd_path "filter/${capability}" "${op}" "${@}" || return 1
         done
         ;;
+    addfilter_fs)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/fs' '+' "${@}"
+        ;;
+    rmfilter_fs)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if  [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/fs' "${op}" "${@}"
+        ;;
     addfilter_walk)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
@@ -1784,6 +1841,12 @@ enable_pid
     Enable PID sandboxing
 disable_pid
     Disable PID sandboxing
+enabled_fs
+    Return true if Filesystem sandboxing is enabled
+enable_fs
+    Enable Filesystem sandboxing
+disable_fs
+    Disable Filesystem sandboxing
 enabled_walk
     Return true if walk sandboxing is enabled
 enable_walk
@@ -1954,6 +2017,14 @@ deny, deny_path glob
     Deny the given glob pattern for path sandboxing
 nodeny, nodeny_path [--all] glob
     Removes the given glob pattern from the denylist for path sandboxing
+allow_fs fstype
+    Allow the given filesystem type for Filesystem sandboxing
+disallow_fs [--all] fstype
+    Removes the given filesystem type from the allowlist for Filesystem sandboxing
+deny_fs fstype
+    Deny the given filesystem type for Filesystem sandboxing
+nodeny_fs [--all] fstype
+    Removes the given filesystem type from the denylist for Filesystem sandboxing
 allow_walk glob
     Allow the given glob pattern for walk sandboxing
 disallow_walk [--all] glob
@@ -2169,6 +2240,10 @@ addfilter, addfilter_path glob
     Adds the given glob pattern to the list of access violation filters for path sandboxing
 rmfilter, rmfilter_path [--all] glob
     Removes the given glob pattern from the list of access violation filters for path sandboxing
+addfilter_fs fstype
+    Adds the given filesystem type to the list of access violation filters for Filesystem sandboxing
+rmfilter_fs [--all] fstype
+    Removes the given filesystem type from the list of access violation filters for Filesystem sandboxing
 addfilter_walk glob
     Adds the given glob pattern to the list of access violation filters for walk sandboxing
 rmfilter_walk [--all] glob
